==> firebase_repository-1.0.48.tar.gz: lib/src/entities/producto_sanitario_entity.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class ProductoSanitarioEntity extends Equatable{
  final String uuid;
  final bool activo;
  final String categoriaUid;
  final double costo;
  final String medida;
  final String nombre;

  ProductoSanitarioEntity(this.uuid, this.activo,this.categoriaUid, this.costo, this.medida,
      this.nombre);

  Map<String, Object> toJson(){
    return {
      'activo': this.activo,
      'categoriaUid': this.categoriaUid,
      'costo': this.costo,
      'medida': this.medida,
      'nombre': this.nombre
    };
  }

  @override
  String toString() {
    return 'ProductoSanitarioEntity{uuid: $uuid, activo: $activo, categoriaUid: $categoriaUid, costo: $costo, medida: $medida, nombre: $nombre}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          super == other &&
              other is ProductoSanitarioEntity &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              activo == other.activo &&
              categoriaUid == other.categoriaUid &&
              costo == other.costo &&
              medida == other.medida &&
              nombre == other.nombre;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      activo.hashCode ^
      categoriaUid.hashCode ^
      costo.hashCode ^
      medida.hashCode ^
      nombre.hashCode;

  static ProductoSanitarioEntity fromSnapshot(DocumentSnapshot snapshot){
    return ProductoSanitarioEntity(
      snapshot.documentID,
      snapshot.data['activo'],
      snapshot.data['categoriaUid'],
      double.parse(snapshot.data['costo'].toString()),
      snapshot.data['medida'],
      snapshot.data['nombre']
    );
  }

  Map<String, Object> toDocument(){
    return {
      'activo': this.activo,
      'categoriaUid': this.categoriaUid,
      'costo': this.costo,
      'medida': this.medida,
      'nombre': this.nombre
    };
  }


}

==> firebase_repository-1.1.24.tar.gz: lib/src/entities/producto_sanitario_entity.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class ProductoSanitarioEntity extends Equatable{
  final String uuid;
  final bool activo;
  final String categoriaUid;
  final double costo;
  final String medida;
  final String nombre;

  ProductoSanitarioEntity(this.uuid, this.activo,this.categoriaUid, this.costo, this.medida,
      this.nombre);

  Map<String, Object> toJson(){
    return {
      'activo': this.activo,
      'categoriaUid': this.categoriaUid,
      'costo': this.costo,
      'medida': this.medida,
      'nombre': this.nombre
    };
  }

  @override
  String toString() {
    return 'ProductoSanitarioEntity{uuid: $uuid, activo: $activo, categoriaUid: $categoriaUid, costo: $costo, medida: $medida, nombre: $nombre}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          super == other &&
              other is ProductoSanitarioEntity &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              activo == other.activo &&
              categoriaUid == other.categoriaUid &&
              costo == other.costo &&
              medida == other.medida &&
              nombre == other.nombre;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      activo.hashCode ^
      categoriaUid.hashCode ^
      costo.hashCode ^
      medida.hashCode ^
      nombre.hashCode;

  static ProductoSanitarioEntity fromSnapshot(DocumentSnapshot snapshot){
    return ProductoSanitarioEntity(
      snapshot.documentID,
      snapshot.data['activo'],
      snapshot.data['categoria'],
      double.parse(snapshot.data['costo'].toString()),
      snapshot.data['medida'],
      snapshot.data['nombre']
    );
  }

  Map<String, Object> toDocument(){
    return {
      'activo': this.activo,
      'categoriaUid': this.categoriaUid,
      'costo': this.costo,
      'medida': this.medida,
      'nombre': this.nombre
    };
  }


}
